<?php
/*
Plugin Name: Google Plus Favicon
Description: This plugin allows you to generate a Google Plus(G+) favicon for your blog, feed logo and admin logo included Apple touch icon. <a href="https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=mypatricks@gmail.com&item_name=Donate%20to%20Patrick%20Chia&item_number=1242543308&amount=3.00&no_shipping=0&no_note=1&tax=0&currency_code=USD&bn=PP%2dDonationsBF&charset=UTF%2d8&return=http://patrick.bloggles.info/">Get a coffee to Patrick</a>
Version: 1.0
Author: Patrick Chia
Author URI: http://patrickchia.com/
Plugin URI: http://patrick.bloggles.info/plugins/
Tags: G+, plus, google, google+, multi-site, wpmu, wordpressmu, images, avatar, avatars, gravatar, personalization, avatar, identicon, OpenAvatar, mybloglog, monsterid, Favatar, favicon, feed,shortcut icon, web site icon, URL icon
Donate link: http://bit.ly/aYeS92
*/

function plus_settings_api_init() {
	add_settings_section('plus_setting_section',
		'G+ Web site icon Settings',
		'plus_setting_section_callback_function',
		'general');
 	
	add_settings_field('plus_id',
		'Google Plus ID',
		'plus_setting_callback_function',
		'general',
		'plus_setting_section');

	register_setting('general','plus_id');
}
 
add_action('admin_init', 'plus_settings_api_init');
 
function plus_setting_section_callback_function() {
	echo '<p>Simply add a Google+ account ID to generate a <a href="http://en.wikipedia.org/wiki/Favicon">favicon</a> for your blog, feed logo and admin logo.<br />Enter your G+ account ID</p>';
}
 
function plus_setting_callback_function() {
	if ( get_option('plus_id') && get_plus_photo() ) {
		$site_icon = str_replace( 'photo.jpg', 's30-c/photo.jpg', get_plus_photo() );
		$site_icon = ' <span><img src="'. $site_icon .'" /></span>';
	}

	echo '<input name="plus_id" id="plus_id" type="text" value="'. get_option('plus_id') .'" class="regular-text" />' . $site_icon;
}

function get_plus_photo(){
	if ( get_option('plus_id') )
		$account = get_option('plus_id');
	else
		return false;

	if ( !$gson = wp_cache_get( 'gplus-fav', 'general' ) ) {
		$google_json_url = esc_url_raw( 'https://www.googleapis.com/buzz/v1/people/'. $account .'/@self?alt=json&key=AIzaSyAEshRzS0eynJ-k_MxMpBLlRUeDlPuJe1Q' );
		$response = wp_remote_get( $google_json_url, array( 'User-Agent' => get_bloginfo('name') ) );
		$response_code = wp_remote_retrieve_response_code( $response );

		if ( 200 == $response_code ) {
			$gson = wp_remote_retrieve_body( $response );
			$gson = json_decode( $gson, true );
			$expire = 900;
			if ( !is_array( $gson ) || isset( $gson['error'] ) ) {
				$gson = 'error';
				$expire = 300;
			}
		} else {
			$gson = 'error';
			$expire = 300;
			wp_cache_add( 'gplus-response-code', $response_code, 'general', $expire);

		}
		wp_cache_add( 'gplus-fav', $gson, 'widget', 86400); //cache for 24 hours

	}

	if ( 'error' != $gson ) :
		foreach ( (array) $gson as $json ) {
			$plus = $json['thumbnailUrl'];
		}

		return $plus;

	else :
		if ( 401 == wp_cache_get( 'gplus-response-code', 'general' ) )
			echo '<!--' . esc_html( sprintf( __( 'Error: Please make sure the Google account is <a href="%s">public</a>.'), 'http://plus.google.com/' ) ) . '-->';
		else
			echo '<!--' . esc_html__('Error: Google Plus did not respond. Please wait a few minutes and refresh this page.') . '-->';

	endif;

	return false;
}

function plus_blog_favicon() {
	if ( get_option('plus_id') && get_plus_photo() ) {
		$apple_icon = str_replace( 'photo.jpg', 's60-c/photo.jpg', get_plus_photo() );
		$favicon_icon =	str_replace( 'photo.jpg', 's16-c/photo.jpg', get_plus_photo() );

		echo '<link rel="apple-touch-icon" href="'. $apple_icon .'" />';
		echo '<link rel="apple-touch-icon-precomposed" href="'. $apple_icon .'" />';
		echo '<link rel="shortcut icon" href="'. $favicon_icon .'" /><!-- G+ Favicon by Patrick http://patrick.bloggles.info/ -->';
	}
}

function plus_admin_logo() {
	if ( get_option('plus_id') && get_plus_photo() ) {
		$admin_logo = str_replace( 'photo.jpg', 's30-c/photo.jpg', get_plus_photo() );

	?>
	<style type="text/css">#header-logo{background: transparent url( <?php echo $admin_logo; ?> ) no-repeat scroll center center;</style>
	<?php
	}
}

function plus_add_feed_logo() {
	if ( get_option('plus_id') && get_plus_photo() ) {
		$feed_logo = str_replace( 'photo.jpg', 's48-c/photo.jpg', get_plus_photo() );

	echo "
   <image>
    <title>". get_bloginfo('name')."</title>
    <url>". $feed_logo ."</url>
    <link>". get_bloginfo('siteurl') ."</link>
   </image><!-- G+ Favicon by Patrick http://patrick.bloggles.info/ -->\n";
	}
}

function plus_plugin_settings( $links ) {
	$settings_link = '<a href="options-general.php">'.__( 'Settings', 'plusfavicon' ).'</a>';
	array_unshift( $links, $settings_link );
	return $links;
}

function plus_add_plugin_settings($links, $file) {
	if ( $file == basename( dirname( __FILE__ ) ).'/'.basename( __FILE__ ) ) {
		$links[] = '<a href="options-general.php">' . __( 'Settings', 'plusfavicon' ) . '</a>';
		$links[] = '<a href="http://bit.ly/aYeS92">' . __( 'Make Donation', 'plusfavicon' ) . '</a>';
	}
	
	return $links;
}

add_action( 'wp_head', "plus_blog_favicon" );
add_action( 'admin_head', 'plus_blog_favicon' );
add_action( 'login_head', 'plus_blog_favicon' );
add_action( 'admin_head', 'plus_admin_logo' );
add_action( 'rss_head', 'plus_add_feed_logo' );
add_action( 'rss2_head', 'plus_add_feed_logo' );
add_action( 'plugin_action_links_'.basename( dirname( __FILE__ ) ).'/'.basename( __FILE__ ), 'plus_plugin_settings', 10, 4 );
add_filter( 'plugin_row_meta', 'plus_add_plugin_settings', 10, 2 );


?>